@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/phpldapadmin/phpldapadmin/export_functions.php,v 1.11 2004/03/19 20:13:08 i18phpldapadmin Exp $
+// $Header: /cvsroot/phpldapadmin/phpldapadmin/export_functions.php,v 1.20 2004/11/03 22:00:52 xrenard Exp $
 
 /**
  * Fuctions and classes for exporting ldap entries to others formats
@@ -26,6 +26,14 @@ $exporters[] = array('output_type'=>'dsml',
 			     'extension' => 'xml'
 			     );
 
+$exporters[] = array('output_type'=>'vcard',
+			     'desc' => 'VCARD 2.1',
+			     'extension' => 'vcf'
+			     );
+$exporters[] = array('output_type'=>'csv',
+			     'desc' => $lang['csv_spreadsheet'],
+			     'extension' => 'csv'
+			     );
 
 /**
  * This class encapsulate informations about the ldap server 
@@ -235,8 +243,7 @@ class PlaExporter extends PlaAbstractExporter{
 class PlaLdapExporter extends PlaAbstractExporter{
   var $entry_id;
   var $results;
-  var $entry_id;
-  var $server_id ;
+  var $server_id;
   var $scope;
   var $entry_array;
   var $num_entries;
@@ -244,7 +251,7 @@ class PlaLdapExporter extends PlaAbstractExporter{
   var $queryFilter;
   var $hasNext;
   var $connection_open_state;
-
+  var $attributes;
   /**
    * Create a PlaLdapExporter object.
    * @param int $server_id the server id
@@ -252,7 +259,7 @@ class PlaLdapExporter extends PlaAbstractExporter{
    * @param String $base_dn the base_dn for the data to export
    * @param String $scope the scope for export
    */
-  function PlaLdapExporter( $server_id , $queryFilter , $base_dn , $scope){
+  function PlaLdapExporter( $server_id , $queryFilter , $base_dn , $scope, $attributes){
     global $lang;
     $this->scope = $scope;
     $this->base_dn = $base_dn;
@@ -264,25 +271,22 @@ class PlaLdapExporter extends PlaAbstractExporter{
     $this->hasNext = 0;
     // boolean to check the state of the connection
     $this->connection_open_state = 0;
-    
+
+    $this->attributes = $attributes;
     // connect to the server
     $this->ds = @pla_ldap_connect( $this->server_id );
-    if( ! $this->ds ) {
-      pla_error( $lang['could_not_connect'] );
-    }
-    else{
-     $this->connection_open_state = 1;
-    }
-   
+    pla_ldap_connection_is_error( $this->ds );
+    $this->connection_open_state = 1;
+
     // get the data to be exported
     if( $this->scope == 'base' )
-      $this->results = @ldap_read( $this->ds, $this->base_dn, $this->queryFilter,array(), 
+      $this->results = @ldap_read( $this->ds, $this->base_dn, $this->queryFilter,$this->attributes, 
 				   0, 0, 0, get_export_deref_setting() );
     elseif( $this->scope == 'one' )
-      $this->results = @ldap_list( $this->ds, $this->base_dn, $this->queryFilter, array(), 
+      $this->results = @ldap_list( $this->ds, $this->base_dn, $this->queryFilter, $this->attributes, 
 				   0, 0, 0, get_export_deref_setting() );
     else // scope == 'sub'
-      $this->results = @ldap_search( $this->ds, $this->base_dn, $this->queryFilter, array(), 
+      $this->results = @ldap_search( $this->ds, $this->base_dn, $this->queryFilter, $this->attributes, 
 				     0, 0, 0, get_export_deref_setting() );
     
     // if no result, there is a something wrong
@@ -575,10 +579,235 @@ class PlaDsmlExporter extends PlaExporter{
 }
 
 
-class MyCustomExporter{
+class PlaVcardExporter extends PlaExporter{
+
+  // mappping one to one attribute
+  var $vcardMapping = array('cn' => 'FN',
+			    'title' => 'TITLE',
+			    'homePhone' => 'TEL;HOME',
+			    'mobile' => 'TEL;CELL',
+			    'mail' => 'EMAIL;Internet',
+			    'labeledURI' =>'URL',
+			    'o' => 'ORG',
+			    'audio' => 'SOUND',
+			    'facsmileTelephoneNumber' =>'TEL;WORK;HOME;VOICE;FAX',
+			    'jpegPhoto' => 'PHOTO;ENCODING=BASE64',
+			    'businessCategory' => 'ROLE',
+			    'description' => 'NOTE'
+			    );
+  
+  var $deliveryAddress  = array("postOfficeBox",
+				"street",
+				"l",
+				"st",
+				"postalCode",
+				"c");
+
+  function PlaVcardExporter($exporter){
+    $this->exporter = $exporter;
+  }
+
+  /**
+   * When doing an exporter, the method export need to be overriden.
+   * A basic implementation is provided here. Customize to your need
+   **/
+
+  function export(){
+
+    // With the method pla->get_ldap_info,
+    // you have access to some values related
+    // to you ldap server
+    $ldap_info = $this->pla_get_ldap_info();
+    $base_dn = $ldap_info->base_dn;
+    $server_id = $ldap_info->server_id;
+    $scope = $ldap_info->scope;
+    $server_name = $ldap_info->server_name;
+    $server_host = $ldap_info->server_host;
+
+    while( $this->pla_has_entry() ){
+      $entry = $this->pla_fetch_entry_array();
+
+      //fetch the dn
+      $dn = $entry['dn'];
+      unset( $entry['dn'] );
+
+      // check the attributes needed for the delivery address
+      // field
+      $addr = "ADR:";
+      foreach( $this->deliveryAddress as $attr_name ){
+	if( isset( $entry[$attr_name] ) ){
+	  $addr .= $entry[$attr_name][0];
+	  unset($entry[$attr_name]);
+	}
+	$addr .= ';';
+      }
+      echo "BEGIN:VCARD$this->br";
+
+      // loop for the attributes
+      foreach( $entry as $attr_name=>$attr_values ){
+
+	// if an attribute of the ldap entry exist
+	// in the mapping array for vcard
+	if( isset( $this->vcardMapping[$attr_name] ) ){
+
+	  // case of organisation. Need to append the
+	  // possible ou attribute
+	  if( 0 == strcasecmp( $attr_name , 'o' )){
+	    echo $this->vcardMapping[$attr_name].":$attr_values[0]";
+	    if( isset($entry['ou'] ) )
+	      foreach( $entry['ou'] as $ou_value ){
+		echo ";$ou_value";
+	      }
+	  }
+	  // the attribute is binary. (to do : need to fold the line)
+	  else if( 0 == strcasecmp( $attr_name,'audio') || 0 == strcasecmp( $attr_name,'jpegPhoto') ){
+	    echo $this->vcardMapping[$attr_name].":$this->br";
+	    echo " ".base64_encode( $attr_values[0]);
+	  }
+	  /*	  else if( $attr_name == "sn"){
+	    echo $this->vcardMapping[$attr_name].":$attr_values[0]";
+	  }
+	  elseif( $attr_name == "homePostalAddress"){
+          }*/
+	  // else just print the value with the relevant attribute name
+	  else{
+	    echo $this->vcardMapping[$attr_name].":$attr_values[0]";
+	  }
+	  echo $this->br;
+	}
+      }
+      // need to check
+      echo "UID:$dn";
+      echo $this->br;
+      echo "VERSION:2.1";
+      echo $this->br;
+      echo $addr;
+      echo $this->br;
+      echo "END:VCARD";
+      echo $this->br;
+    }// end while
+  }
+}
+
+
+
+
+/**
+ * Export to cvs format
+ *
+ * @author Glen Ogilvie
+ */
+
+class PlaCSVExporter extends PlaExporter{
+
+  function PlaCSVExporter($exporter){
+    $this->exporter = $exporter;
+  }
+  
+  /**
+   * When doing an exporter, the method export need to be overriden.
+   * A basic implementation is provided here. Customize to your need
+   **/
+  
+  var $separator = ",";
+  var $qualifier = '"';
+  var $multivalue_separator = " | ";
+  var $escapeCode = '"';
+  
+  function export(){
+    
+    // With the method pla->get_ldap_info,
+    // you have access to some values related
+    // to you ldap server
+    $ldap_info = $this->pla_get_ldap_info();
+    $base_dn = $ldap_info->base_dn;
+    $server_id = $ldap_info->server_id;
+    $scope = $ldap_info->scope;
+    $server_name = $ldap_info->server_name;
+    $server_host = $ldap_info->server_host;
+    
+    $entries = array();
+    $headers = array();
+		
+    // go thru and find all the attribute names first.  This is needed, because, otherwise we have
+    // no idea as to which search attributes were actually populated with data
+    while( $this->pla_has_entry() ) {
+      $entry = $this->pla_fetch_entry_array();
+      foreach (array_keys($entry) as $key) {
+	if (!in_array($key, $headers)) 
+	  array_push($headers,$key);
+      }
+      array_push($entries, $entry);
+    }
+    
+    $num_headers = count($headers);
+    
+    // print out the headers
+    for ($i = 0; $i < $num_headers; $i++) {
+      echo $this->qualifier. $headers[$i].$this->qualifier;
+      if ($i < $num_headers-1) 
+	echo $this->separator;
+    }
+    
+    array_shift($headers);
+    $num_headers--;
+    
+    echo $this->br;
+	
+    // loop on every entry
+    foreach ($entries as $entry) {
+      
+      //print the dn
+      $dn = $entry['dn'];
+      unset( $entry['dn'] );
+      echo $this->qualifier. $this->LdapEscape($dn).$this->qualifier.$this->separator;
+      
+      // print the attributes
+      for($j=0;$j<$num_headers;$j++){
+
+	$attr_name = $headers[$j];
+
+	echo $this->qualifier;
+	if (key_exists($attr_name, $entry)) {
+	  $binary_attribute = is_attr_binary( $server_id, $attr_name )?1:0;
+	  
+	  $attr_values = $entry[$attr_name];
+	  
+	  $num_attr_values = count( $attr_values );
+	  for( $i=0 ; $i<$num_attr_values; $i++){
+	    if($binary_attribute)
+	      echo base64_encode($attr_values[$i]);
+	    else
+	      echo $this->LdapEscape($attr_values[$i]);
+	    
+	    if($i < $num_attr_values - 1)
+	      echo $this->multivalue_separator;
+	    
+	  }
+	}// end if key
+	echo $this->qualifier;
+	if( $j < $num_headers - 1 )
+	  echo $this->separator;
+      }
+          echo $this->br;
+    }
+  }//end export
+  
+  // function to escape data, where the qualifier happens to also 
+  // be in the data.
+  function LdapEscape ($var) {
+    return str_replace($this->qualifier, $this->escapeCode.$this->qualifier, $var);
+  }
+}
+
+
+
+
+
+class MyCustomExporter extends PlaExporter{
 
   function MyCutsomExporter($exporter){
-    $this->exporter = $exporer;
+    $this->exporter = $exporter;
   }
 
   /**
