@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/phpldapadmin/phpldapadmin/lang/en.php,v 1.65 2004/04/26 13:07:03 uugdave Exp $
+// $Header: /cvsroot/phpldapadmin/phpldapadmin/lang/en.php,v 1.104 2004/12/10 04:43:17 uugdave Exp $
 
 
 /*        ---   INSTRUCTIONS FOR TRANSLATORS   ---
@@ -7,10 +7,12 @@
  * If you want to write a new language file for your language,
  * please submit the file on SourceForge:
  *
- * https://sourceforge.net/tracker/?func=add&group_id=61828&atid=498548
+ *   https://sourceforge.net/tracker/?func=add&group_id=61828&atid=498548
  *
  * Use the option "Check to Upload and Attach a File" at the bottom
  *
+ * Read the doc/README-translation.txt for translation instructions.
+ *
  * Thank you!
  *
  */
@@ -29,13 +31,22 @@ $lang['search_for_entries_whose'] = 'Search for entries whose';
 $lang['base_dn'] = 'Base DN';
 $lang['search_scope'] = 'Search Scope';
 $lang['show_attributes'] = 'Show Attributtes';
+$lang['attributes'] = 'Attributes';
 $lang['Search'] = 'Search';
 $lang['predefined_search_str'] = 'Select a predefined search';
 $lang['predefined_searches'] = 'Predefined Searches';
 $lang['no_predefined_queries'] = 'No queries have been defined in config.php.';
+$lang['export_results'] = 'export results';
+$lang['unrecoginzed_search_result_format'] = 'Unrecognized search result format: %s';
+$lang['format'] = 'Format';
+$lang['list'] = 'list';
+$lang['table'] = 'table';
+$lang['bad_search_display'] = 'Your config.php specifies an invalid value for $default_search_display: %s. Please fix it';
+$lang['page_n'] = 'Page %d';
+$lang['no_results'] = 'The search found no results.';
 
 // Tree browser
-$lang['request_new_feature'] = 'Request a new feature';
+$lang['request_new_feature'] = 'Request feature';
 $lang['report_bug'] = 'Report a bug';
 $lang['schema'] = 'schema';
 $lang['search'] = 'search';
@@ -44,7 +55,7 @@ $lang['info'] = 'info';
 $lang['import'] = 'import';
 $lang['refresh'] = 'refresh';
 $lang['logout'] = 'logout';
-$lang['create_new'] = 'Create New';
+$lang['create_new'] = 'Create new entry here';
 $lang['view_schema_for'] = 'View schema for';
 $lang['refresh_expanded_containers'] = 'Refresh all expanded containers for';
 $lang['create_new_entry_on'] = 'Create a new entry on';
@@ -53,6 +64,8 @@ $lang['view_server_info'] = 'View server-supplied information';
 $lang['import_from_ldif'] = 'Import entries from an LDIF file';
 $lang['logout_of_this_server'] = 'Logout of this server';
 $lang['logged_in_as'] = 'Logged in as: ';
+$lang['this_base_dn_is_not_valid'] = 'This is not a valid DN.';
+$lang['this_base_dn_does_not_exist'] = 'This entry does not exist.';
 $lang['read_only'] = 'read only';
 $lang['read_only_tooltip'] = 'This attribute has been flagged as read only by the phpLDAPadmin administrator';
 $lang['could_not_determine_root'] = 'Could not determine the root of your LDAP tree.';
@@ -61,6 +74,8 @@ $lang['please_specify_in_config'] = 'Please specify it in config.php';
 $lang['create_new_entry_in'] = 'Create a new entry in';
 $lang['login_link'] = 'Login...';
 $lang['login'] = 'login';
+$lang['base_entry_does_not_exist'] = 'The base entry does not exist.';
+$lang['create_it'] = 'Create it?';
 
 // Entry display
 $lang['delete_this_entry'] = 'Delete this entry';
@@ -68,6 +83,7 @@ $lang['delete_this_entry_tooltip'] = 'You will be prompted to confirm this decis
 $lang['copy_this_entry'] = 'Copy this entry';
 $lang['copy_this_entry_tooltip'] = 'Copy this object to another location, a new DN, or another server';
 $lang['export'] = 'Export';
+$lang['export_lcase'] = 'export';
 $lang['export_tooltip'] = 'Save a dump of this object';
 $lang['export_subtree_tooltip'] = 'Save a dump of this object and all of its children';
 $lang['export_subtree'] = 'Export subtree';
@@ -101,6 +117,7 @@ $lang['no_new_binary_attrs_available'] = 'no new binary attributes available for
 $lang['binary_value'] = 'Binary value';
 $lang['add_new_binary_attr'] = 'Add new binary attribute';
 $lang['alias_for'] = 'Note: \'%s\' is an alias for \'%s\'';
+$lang['required_for'] = 'Required attribute for objectClass(es) %s';
 $lang['download_value'] = 'download value';
 $lang['delete_attribute'] = 'delete attribute';
 $lang['true'] = 'true';
@@ -118,10 +135,12 @@ $lang['schema_retrieve_error_1']='The server does not fully support the LDAP pro
 $lang['schema_retrieve_error_2']='Your version of PHP does not correctly perform the query.';
 $lang['schema_retrieve_error_3']='Or lastly, phpLDAPadmin doesn\'t know how to fetch the schema for your server.';
 $lang['jump_to_objectclass'] = 'Jump to an objectClass';
+$lang['view_schema_for_oclass'] = 'View the schema description for this objectClass';
 $lang['jump_to_attr'] = 'Jump to an attribute type';
 $lang['jump_to_matching_rule'] = 'Jump to a matching rule';
 $lang['schema_for_server'] = 'Schema for server';
 $lang['required_attrs'] = 'Required Attributes';
+$lang['required'] = 'required';
 $lang['optional_attrs'] = 'Optional Attributes';
 $lang['optional_binary_attrs'] = 'Optional Binary Attributes';
 $lang['OID'] = 'OID';
@@ -144,7 +163,7 @@ $lang['characters']='characters';
 $lang['used_by_objectclasses']='Used by objectClasses';
 $lang['used_by_attributes']='Used by Attributes';
 $lang['maximum_length']='Maximum Length';
-$lang['attributes']='Attribute Types';
+$lang['attribute_types']='Attribute Types';
 $lang['syntaxes']='Syntaxes';
 $lang['matchingrules']='Matching Rules';
 $lang['oid']='OID';
@@ -157,6 +176,7 @@ $lang['user_modification']='User Modification';
 $lang['usage']='Usage';
 $lang['could_not_retrieve_schema_from']='Could not retrieve schema from';
 $lang['type']='Type';
+$lang['no_such_schema_item'] = 'No such schema item: "%s"';
 
 // Deleting entries
 $lang['entry_deleted_successfully'] = 'Entry %s deleted successfully.';
@@ -214,6 +234,7 @@ $lang['could_not_connect'] = 'Could not connect to LDAP server.';
 $lang['could_not_connect_to_host_on_port'] = 'Could not connect to "%s" on port "%s"';
 $lang['could_not_perform_ldap_mod_add'] = 'Could not perform ldap_mod_add operation.';
 $lang['bad_server_id_underline'] = 'Bad server_id: ';
+$lang['home'] = 'Home';
 $lang['success'] = 'Success';
 $lang['server_colon_pare'] = 'Server: ';
 $lang['look_in'] = 'Looking in: ';
@@ -272,6 +293,8 @@ $lang['must_choose_template'] = 'You must choose a template';
 $lang['invalid_template'] = '%s is an invalid template';
 $lang['using_template'] = 'using template';
 $lang['go_to_dn'] = 'Go to %s';
++$lang['structural_object_class_cannot_remove'] = 'This is a structural ObjectClass and cannot be removed.';
++$lang['structural'] = 'structural';
 
 //copy_form.php
 $lang['copyf_title_copy'] = 'Copy ';
@@ -283,6 +306,7 @@ $lang['copyf_note'] = 'Hint: Copying between different servers only works if the
 $lang['copyf_recursive_copy'] = 'Recursively copy all children of this object as well.';
 $lang['recursive_copy'] = 'Recursive copy';
 $lang['filter'] = 'Filter';
+$lang['search_filter'] = 'Search Filter';
 $lang['filter_tooltip'] = 'When performing a recursive copy, only copy those entries which match this filter';
 
 //create.php
@@ -295,24 +319,23 @@ $lang['create_could_not_add'] = 'Could not add the object to the LDAP server.';
 $lang['createf_create_object'] = 'Create Object';
 $lang['createf_choose_temp'] = 'Choose a template';
 $lang['createf_select_temp'] = 'Select a template for the creation process';
-$lang['createf_proceed'] = 'Proceed';
+$lang['save_as_file'] = 'Save as file';
 $lang['rdn_field_blank'] = 'You left the RDN field blank.';
 $lang['container_does_not_exist'] = 'The container you specified (%s) does not exist. Please try again.';
 $lang['no_objectclasses_selected'] = 'You did not select any ObjectClasses for this object. Please go back and do so.';
-$lang['hint_structural_oclass'] = 'Hint: You must choose at least one structural objectClass';
+$lang['hint_structural_oclass'] = 'Hint: You must choose exactly one structural objectClass (shown in bold above)';
 
 //creation_template.php
 $lang['ctemplate_on_server'] = 'On server';
 $lang['ctemplate_no_template'] = 'No template specified in POST variables.';
-$lang['ctemplate_config_handler'] = 'Your config specifies a handler of';
-$lang['ctemplate_handler_does_not_exist'] = 'for this template. But, this handler does not exist in the templates/creation directory.';
+$lang['template_not_readable'] = 'Your config specifies a handler of "%s" for this template but this file is not readable because the permissions are too strict.';
+$lang['template_does_not_exist'] = 'Your config specifies a handler of "%s" for this template but this handler does not exist in the templates/creation directory.';
 $lang['create_step1'] = 'Step 1 of 2: Name and ObjectClass(es)';
 $lang['create_step2'] = 'Step 2 of 2: Specify attributes and values';
 $lang['relative_distinguished_name'] = 'Relative Distinguished Name';
 $lang['rdn'] = 'RDN';
 $lang['rdn_example'] = '(example: cn=MyNewPerson)';
 $lang['container'] = 'Container';
-$lang['alias_for'] = 'Alias for %s';
 
 // search.php
 $lang['you_have_not_logged_into_server'] = 'You have not logged into the selected server yet, so you cannot perform searches on it.';
@@ -343,7 +366,7 @@ $lang['ends with'] = 'ends with';
 $lang['sounds like'] = 'sounds like';
 
 // server_info.php
-$lang['could_not_fetch_server_info'] = 'Could not retrieve LDAP information from the server';
+$lang['could_not_fetch_server_info'] = 'Could not retrieve LDAP information from the server. This may be due to a <a href="http://bugs.php.net/bug.php?id=29587">bug</a> in your version of PHP or perhaps your LDAP server has access control specified that prevents LDAP clients from accessing the RootDSE.';
 $lang['server_info_for'] = 'Server info for: ';
 $lang['server_reports_following'] = 'Server reports the following information about itself';
 $lang['nothing_to_report'] = 'This server has nothing to report.';
@@ -368,6 +391,18 @@ $lang['welcome_note'] = 'Use the menu to the left to navigate';
 $lang['credits'] = 'Credits';
 $lang['changelog'] = 'ChangeLog';
 $lang['donate'] = 'Donate';
+$lang['pla_logo'] = 'phpLDAPadmin logo';
+
+// Donate.php
+$lang['donation_instructions'] = 'To donate funds to the phpLDAPadmin project, use one of the PayPal buttons below.';
+$lang['donate_amount'] = 'Donate %s';
+$lang['wish_list_option'] = 'Or perhaps you would prefer to purchase an gift for a phpLDAPadmin developer.';
+$lang['wish_list'] = 'View Dave\'s phpLDAPadmin wish list';
+
+$lang['purge_cache'] = 'Purge caches';
+$lang['no_cache_to_purge'] = 'No cache to purge.';
+$lang['done_purging_caches'] = 'Purged %s bytes of cache.';
+$lang['purge_cache_tooltip'] = 'Purge all cached data in phpLDAPadmin, including server schemas.';
 
 // view_jpeg_photo.php
 $lang['unsafe_file_name'] = 'Unsafe file name: ';
@@ -393,6 +428,8 @@ $lang['auto_uid_invalid_value'] = 'You specified an invalid value for auto_uid_n
 $lang['error_auth_type_config'] = 'Error: You have an error in your config file. The only three allowed values
                                     for auth_type in the $servers section are \'session\', \'cookie\', and \'config\'. You entered \'%s\',
                                     which is not allowed. ';
+$lang['unique_attrs_invalid_credential'] = 'Unable to bind to <b>%s</b> with your with unique_attrs credentials. Please check your configuration file.'; 
+$lang['unique_attr_failed'] = 'Your attempt to add <b>%s</b> (<i>%s</i>) to <br><b>%s</b><br> is NOT allowed. That attribute/value belongs to another entry.<p>You might like to <a href=\'%s\'>search</a> for that entry.';
 $lang['php_install_not_supports_tls'] = 'Your PHP install does not support TLS.';
 $lang['could_not_start_tls'] = 'Could not start TLS. Please check your LDAP server configuration.';
 $lang['could_not_bind_anon'] = 'Could not bind anonymously to server.';
@@ -439,7 +476,6 @@ $lang['ferror_congrats_found_bug'] = 'Congratulations! You found a bug in phpLDA
 //ldif_import_form
 $lang['import_ldif_file_title'] = 'Import LDIF File';
 $lang['select_ldif_file'] = 'Select an LDIF file:';
-$lang['select_ldif_file_proceed'] = 'Proceed &gt;&gt;';
 $lang['dont_stop_on_errors'] = 'Don\'t stop on errors';
 
 //ldif_import
@@ -450,7 +486,7 @@ $lang['modify_action'] = 'Modifying...';
 $lang['warning_no_ldif_version_found'] = 'No version found. Assuming 1.';
 $lang['valid_dn_line_required'] = 'A valid dn line is required.';
 $lang['missing_uploaded_file'] = 'Missing uploaded file.';
-$lang['no_ldif_file_specified.'] = 'No LDIF file specified. Please try again.';
+$lang['no_ldif_file_specified'] = 'No LDIF file specified. Please try again.';
 $lang['ldif_file_empty'] = 'Uploaded LDIF file is empty.';
 $lang['empty'] = 'empty';
 $lang['file'] = 'File';
@@ -477,9 +513,11 @@ $lang['searching'] = 'Searching...';
 $lang['size_limit_exceeded'] = 'Notice, search size limit exceeded.';
 $lang['entry'] = 'Entry';
 $lang['ldif_export_for_dn'] = 'LDIF Export for: %s';
-$lang['generated_on_date'] = 'Generated by phpLDAPadmin on %s';
+$lang['generated_on_date'] = 'Generated by phpLDAPadmin ( http://phpldapadmin.sourceforge.net/ ) on %s';
 $lang['total_entries'] = 'Total Entries';
 $lang['dsml_export_for_dn'] = 'DSLM Export for: %s';
+$lang['include_system_attrs'] = 'Include system attributes';
+$lang['csv_spreadsheet'] = 'CSV (Spreadsheet)';
 
 // logins
 $lang['could_not_find_user'] = 'Could not find a user "%s"';
@@ -508,6 +546,7 @@ $lang['no_deletes_in_read_only'] = 'Deletes not allowed in read only mode.';
 $lang['error_calling_mass_delete'] = 'Error calling mass_delete.php. Missing mass_delete in POST vars.';
 $lang['mass_delete_not_array'] = 'mass_delete POST var is not an array.';
 $lang['mass_delete_not_enabled'] = 'Mass deletion is not enabled. Please enable it in config.php before proceeding.';
+$lang['search_attrs_wrong_count'] = 'Your config.php has an error. The number of attributes in $search_attributes and $search_attributes_display is different';
 $lang['mass_deleting'] = 'Mass Deleting';
 $lang['mass_delete_progress'] = 'Deletion progress on server "%s"';
 $lang['malformed_mass_delete_array'] = 'Malformed mass_delete array.';
@@ -524,4 +563,95 @@ $lang['no_rdn_change'] = 'You did not change the RDN';
 $lang['invalid_rdn'] = 'Invalid RDN value';
 $lang['could_not_rename'] = 'Could not rename the entry';
 
+// General errors
+$lang['php5_unsupported'] = 'phpLDAPadmin does not yet support PHP 5. You will likely encounter many weird problems if you continue.';
+$lang['mismatched_search_attr_config'] = 'Your configuration has an error. $search_attributes must have the same number of attributes as $search_attributes_display.';
+
+// Password checker
+$lang['passwords_match'] = 'Passwords match!';
+$lang['passwords_do_not_match'] = 'Passwords do not match!';
+$lang['password_checker_tool'] = 'Password Checker Tool';
+$lang['compare'] = 'Compare';
+$lang['to'] = 'To';
+
+// Templates
+$lang['using'] = 'Using the';
+$lang['template'] = 'template';
+$lang['switch_to'] = 'You may switch to the ';
+$lang['default_template'] = 'default template';
+
+// template_config
+$lang['user_account'] = 'User Account (posixAccount)';
+$lang['address_book'] = 'Address Book Entry (inetOrgPerson)';
+$lang['kolab_user'] = 'Kolab User Entry';
+$lang['organizational_unit'] = 'Organizational Unit';
+$lang['organizational_role'] = 'Organizational Role';
+$lang['posix_group'] = 'Posix Group';
+$lang['samba_machine'] = 'Samba NT Machine';
+$lang['samba3_machine'] = 'Samba 3 NT Machine';
+$lang['samba_user'] = 'Samba User';
+$lang['samba3_user'] = 'Samba 3 User';
+$lang['samba3_group'] = 'Samba 3 Group Mapping';
+$lang['dns_entry'] = 'DNS Entry';
+$lang['simple_sec_object'] = 'Simple Security Object';
+$lang['courier_mail_account'] = 'Courier Mail Account';
+$lang['courier_mail_alias'] = 'Courier Mail Alias';
+$lang['ldap_alias'] = 'LDAP Alias';
+$lang['custom'] = 'Custom';
+$lang['samba_domain_name'] = 'My Samba domain Name';
+$lang['administrators'] = 'Administrators';
+$lang['users'] = 'Users';
+$lang['guests'] = 'Guests';
+$lang['power_users'] = 'Power Users';
+$lang['account_ops'] = 'Account Operators';
+$lang['server_ops'] = 'Server Operators';
+$lang['print_ops'] = 'Print Operators';
+$lang['backup_ops'] = 'backup Operators';
+$lang['replicator'] = 'Replicator';
+$lang['unable_smb_passwords'] = ' Unable to create the Samba passwords. Please, check the configuration in template_config.php';
+
+// Samba Account Template
+$lang['samba_account'] = 'Samba Account';
+$lang['samba_account_lcase'] = 'samba account';
+
+// New User (Posix) Account
+$lang['t_new_user_account'] = 'New User Account';
+$lang['t_hint_customize'] = 'Hint: To customize this template, edit the file templates/creation/new_user_template.php';
+$lang['t_name'] = 'Name';
+$lang['t_first_name'] = 'First name';
+$lang['t_last_name'] = 'Last name';
+$lang['t_common_name'] = 'Common name';
+$lang['t_user_name'] = 'User Name';
+$lang['t_password'] = 'Password';
+$lang['t_encryption'] = 'Encryption';
+$lang['t_login_shell'] = 'Login Shell';
+$lang['t_home_dir'] = 'Home Directory';
+$lang['t_uid_number'] = 'UID Number';
+$lang['t_auto_det'] = '(automatically determined)';
+$lang['t_group'] = 'Group';
+$lang['t_gid_number'] = 'GID Number';
+$lang['t_err_passwords'] = 'Your passwords don\'t match. Please go back and try again.';
+$lang['t_err_field_blank'] = 'You cannot leave the %s blank. Please go back and try again.';
+$lang['t_err_field_num'] = 'You can only enter numeric values for the %s field. Please go back and try again.';
+$lang['t_err_bad_container'] = 'The container you specified (%s) does not exist. Please go back and try again.';
+$lang['t_confirm_account_creation'] = 'Confirm account creation';
+$lang['t_secret'] = '[secret]';
+$lang['t_create_account'] = 'Create Account';
+
+// New Address Template
+$lang['t_new_address'] = 'New Address Book Entry';
+$lang['t_organization'] = 'Organization';
+$lang['t_address'] = 'Address';
+$lang['t_city'] = 'City';
+$lang['t_postal_code'] = 'Postal code';
+$lang['t_street'] = 'Street';
+$lang['t_work_phone'] = 'Work phone';
+$lang['t_fax'] = 'Fax';
+$lang['t_mobile'] = 'Mobile';
+$lang['t_email'] = 'Email';
+$lang['t_container'] = 'Container';
+$lang['t_err_cn_blank'] = 'You cannot leave the Common Name blank. Please go back and try again.';
+$lang['t_confim_creation'] = 'Confirm entry creation:';
+$lang['t_create_address'] = 'Create Address';
+
 ?>
