@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/phpldapadmin/phpldapadmin/lang/es.php,v 1.17 2004/05/10 12:31:04 uugdave Exp $
+// $Header: /cvsroot/phpldapadmin/phpldapadmin/lang/es.php,v 1.19 2004/06/07 13:01:28 uugdave Exp $
 
 
 // Search form
@@ -89,7 +89,7 @@ $lang['no_new_attrs_available'] = 'No hay atributos nuevos disponibles para este
 $lang['binary_value'] = 'Valor binario';
 $lang['add_new_binary_attr'] = 'Agregar valor binario';
 $lang['add_new_binary_attr_tooltip'] = 'Agregar atributo/valor binario de un archivo';
-$lang['alias_for'] = 'Sinnimo para';
+$lang['alias_for'] = '%s es sinnimo para %s';
 $lang['download_value'] = 'Descargar valor';
 $lang['delete_attribute'] = 'Borrar atributo';
 $lang['true'] = 'verdad';
@@ -203,7 +203,7 @@ $lang['createf_proceed'] = 'Proceder';
 $lang['ctemplate_on_server'] = 'Al servidor';
 $lang['ctemplate_no_template'] = 'No se ha especificado ninguna plantilla en las variables del POST.';
 $lang['ctemplate_config_handler'] = 'Tu configuracin especifica un manejador de';
-$lang['ctemplate_handler_does_not_exist'] = 'para esta plantilla. Pero este manejador no existe en el directorio \'plantilla/creacin\'.';
+$lang['ctemplate_handler_does_not_exist'] = 'para esta plantilla. Pero este manejador no existe en el directorio \'templates/creation\'.';
 
 // search.php
 $lang['you_have_not_logged_into_server'] = 'An no te has autenticado en ell servidor seleccionado, no puedes hacer ninguna bsqueda.';
