@@ -11,7 +11,7 @@
  *
  * Thank you!
  *
- * $Header: /cvsroot/phpldapadmin/phpldapadmin/lang/fr.php,v 1.24 2004/03/07 17:37:41 xrenard Exp $
+ * $Header: /cvsroot/phpldapadmin/phpldapadmin/lang/fr.php,v 1.25 2004/05/29 04:07:02 uugdave Exp $
  */
 
 /*
@@ -474,7 +474,7 @@ $lang['searching'] = 'Recherche...';
 $lang['size_limit_exceeded'] = 'Notice, la limite de taille pour la recherche est atteinte.';
 $lang['entry'] = 'Entre';
 $lang['ldif_export_for_dn'] = 'Export LDIF pour: %s';
-$lang['generated_on_date'] = 'Gener par phpLDAPadmin le %s';
+$lang['generated_on_date'] = 'Gener par phpLDAPadmin ( http://phpldapadmin.sourceforge.net/ ) le %s';
 $lang['total_entries'] = 'Nombre d\'entres';
 $lang['dsml_export_for_dn'] = 'Export DSML pour: %s';
 
