@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/phpldapadmin/phpldapadmin/lang/recoded/pl.php,v 1.8 2004/04/26 19:21:40 i18phpldapadmin Exp $
+// $Header: /cvsroot/phpldapadmin/phpldapadmin/lang/recoded/pl.php,v 1.10 2004/12/09 14:16:15 uugdave Exp $
 
 /*        ---   INSTRUCTIONS FOR TRANSLATORS   ---
  *
@@ -10,14 +10,16 @@
  *
  * Use the option "Check to Upload and Attach a File" at the bottom
  *
+ * Read the doc/README-translation.txt for translation instructions.
+ *
  * Thank you!
  *
  */
 
-/* $Header: /cvsroot/phpldapadmin/phpldapadmin/lang/recoded/pl.php,v 1.8 2004/04/26 19:21:40 i18phpldapadmin Exp $
+/* $Header: /cvsroot/phpldapadmin/phpldapadmin/lang/recoded/pl.php,v 1.10 2004/12/09 14:16:15 uugdave Exp $
  * initial translation from Piotr (DrFugazi) Tarnowski on Version 0.9.3
  */
-// Based on en.php version 1.64
+// Based on en.php version 1.80
 
 // Search form
 $lang['simple_search_form_str'] = 'Wyszukiwanie proste';
@@ -27,13 +29,20 @@ $lang['search_for_entries_whose'] = 'Szukaj wpisów w których';
 $lang['base_dn'] = 'Bazowa DN';
 $lang['search_scope'] = 'Zakres przeszukiwania';
 $lang['show_attributes'] = 'Pokaż atrybuty';
+$lang['attributes'] = 'Atrybuty';
 $lang['Search'] = 'Szukaj';
 $lang['equals'] = 'równa się';
 $lang['contains'] = 'zawiera';
 $lang['predefined_search_str'] = 'Wybierz predefiniowane wyszukiwanie';
 $lang['predefined_searches'] = 'Predefiniowane wyszukiwania';
 $lang['no_predefined_queries'] = 'Brak zdefiniowanych zapytań w config.php.';
-
+$lang['export_results'] = 'wyeksportuj wyniki';
+$lang['unrecoginzed_search_result_format'] = 'Nierozpoznany format wyniku wyszukiwania: %s';
+$lang['format'] = 'Format';
+$lang['list'] = 'lista';
+$lang['table'] = 'tabela';
+$lang['bad_search_display'] = 'W Twojej konfiguracji (config.php) określona jest nieprawidłowa wartość dla $default_search_display: %s. Proszę to poprawić';
+		      
 // Tree browser
 $lang['request_new_feature'] = 'Zgłoś zapotrzebowanie na nową funkcjonalność';
 $lang['report_bug'] = 'Zgłoś błąd (report a bug)';
@@ -68,6 +77,7 @@ $lang['delete_this_entry_tooltip'] = 'Będziesz poproszony/a o potwierdzenie tej
 $lang['copy_this_entry'] = 'Skopiuj ten wpis';
 $lang['copy_this_entry_tooltip'] = 'Skopiuj ten obiekt do innej lokalizacji, nowej DN, lub do innego serwera';
 $lang['export'] = 'Eksportuj';
+$lang['export_lcase'] = 'eksportuj';
 $lang['export_tooltip'] = 'Zapisz zrzut tego obiektu';
 $lang['export_subtree_tooltip'] = 'Zapisz zrzut tego obiektu i wszystkich potomnych';
 $lang['export_subtree'] = 'Eksportuj całe poddrzewo';
@@ -101,6 +111,7 @@ $lang['no_new_binary_attrs_available'] = 'brak nowych atrybutów binarnych dla t
 $lang['binary_value'] = 'Wartość binarna';
 $lang['add_new_binary_attr'] = 'Dodaj nowy atrybut binarny';
 $lang['alias_for'] = 'Uwaga: \'%s\' jest aliasem dla \'%s\'';
+$lang['required_for'] = 'Atrybut wymagany dla klas(y) obiektu %s';
 $lang['download_value'] = 'pobierz (download) wartość';
 $lang['delete_attribute'] = 'usuń atrybut';
 $lang['true'] = 'prawda';
@@ -118,10 +129,12 @@ $lang['schema_retrieve_error_1']='Serwer nie wspiera w pełni protokołu LDAP.';
 $lang['schema_retrieve_error_2']='Twoja wersja PHP niepoprawnie wykonuje zapytanie.';
 $lang['schema_retrieve_error_3']='Lub w ostateczności, phpLDAPadmin nie wie jak uzyskać schemat dla Twojego serwera.';
 $lang['jump_to_objectclass'] = 'Skocz do klasy obiektu';
+$lang['view_schema_for_oclass'] = 'Pokaż opis schematu dla tej klasy obiektu';
 $lang['jump_to_attr'] = 'Skocz do typu atrybutu';
 $lang['jump_to_matching_rule'] = 'Skocz do reguły dopasowania';
 $lang['schema_for_server'] = 'Schemat dla serwera';
 $lang['required_attrs'] = 'Wymagane atrybuty';
+$lang['required'] = 'wymagane';
 $lang['optional_attrs'] = 'Opcjonalne atrybuty';
 $lang['optional_binary_attrs'] = 'Opcjonalne atrybuty binarne';
 $lang['OID'] = 'OID';
@@ -144,7 +157,7 @@ $lang['characters']='znaki/ów';
 $lang['used_by_objectclasses']='Używane przez klasy obiektu';
 $lang['used_by_attributes']='Używane przez atrybuty';
 $lang['maximum_length']='Maksymalna długość';
-$lang['attributes']='Typy atrybutów';
+$lang['attribute_types']='Typy atrybutów';
 $lang['syntaxes']='Składnie';
 $lang['objectclasses']='Klasy Obiektu';
 $lang['matchingrules']='Reguły Dopasowania';
@@ -158,6 +171,7 @@ $lang['user_modification']='Modyfikacja użytkownika';
 $lang['usage']='Użycie';
 $lang['could_not_retrieve_schema_from']='Nie można uzyskać schematu z';
 $lang['type']='Typ';
+$lang['no_such_schema_item'] = 'Nie ma takiej pozycji w schemacie: "%s"';
 
 // Deleting entries
 $lang['entry_deleted_successfully'] = 'Wpis %s został pomyślnie usunięty.';
@@ -183,6 +197,12 @@ $lang['no_dn_specified'] = 'Nie określono DN';
 // Adding attributes
 $lang['left_attr_blank'] = 'Pozostawiłeś/aś pustą wartość atrybutu. Proszę wrócić i spróbować ponownie.';
 $lang['failed_to_add_attr'] = 'Błąd podczas dodawania atrybutu.';
+$lang['file_empty'] = 'Wybrany plik jest pusty lub nie istnieje. Wróć i spróbuj ponownie.';
+$lang['invalid_file'] = 'Błąd bezpieczeństwa: Załadowany plik może stanowić zagrożenie.';
+$lang['warning_file_uploads_disabled'] = 'Twoja konfiguracja PHP uniemożliwia załadowanie plików. Proszę sprawdzić php.ini przed kontynuacją.';
+$lang['uploaded_file_too_big'] = 'Załadowany plik jest zbyt duży. Proszę sprawdzić ustawienie upload_max_size w php.ini';
+$lang['uploaded_file_partial'] = 'Wybrany plik został tylko częściowo załadowany, prawdopodobnie wystąpił błąd w sieci.';
+$lang['max_file_size'] = 'Maksymalny rozmiar pliku: %s';
 
 // Updating values
 $lang['modification_successful'] = 'Modyfikacja zakończona pomyślnie.';
@@ -262,6 +282,8 @@ $lang['must_choose_template'] = 'Musisz wybrać szablon';
 $lang['invalid_template'] = '%s nie jest prawidłowym szablonem';
 $lang['using_template'] = 'wykorzystując szablon';
 $lang['go_to_dn'] = 'Idź do %s';
+$lang['structural_object_class_cannot_remove'] = 'To jest strukturalna klasa obiektu i nie może zostać usunięta.';
+$lang['structural'] = 'strukturalna';
 
 //copy_form.php
 $lang['copyf_title_copy'] = 'Kopiuj ';
@@ -289,7 +311,7 @@ $lang['createf_proceed'] = 'Dalej';
 $lang['rdn_field_blank'] = 'Pozostawiłeś/aś puste pole RDN.';
 $lang['container_does_not_exist'] = 'Kontener który określiłeś/aś (%s) nie istnieje. Spróbuj ponownie.';
 $lang['no_objectclasses_selected'] = 'Nie wybrałeś/aś żadnych Klas Obiektu dla tego obiektu. Wróć proszę i zrób to.';
-$lang['hint_structural_oclass'] = 'Wskazówka: Musisz wybrać co najmniej jedną strukturalną klasę obiektu';
+$lang['hint_structural_oclass'] = 'Wskazówka: Musisz wybrać co najmniej jedną strukturalną klasę obiektu (wyróżnioną pogrubieniem)';
 	      
 //creation_template.php
 $lang['ctemplate_on_server'] = 'Na serwerze';
@@ -350,10 +372,13 @@ $lang['go_back'] = 'Powrót';
 
 // welcome.php
 $lang['welcome_note'] = 'Użyj menu z lewej strony do nawigacji';
-$lang['credits'] = 'Credits';
-$lang['changelog'] = 'ChangeLog';
-$lang['donate'] = 'Donate';
-
+$lang['credits'] = 'Lista płac';
+$lang['changelog'] = 'Historia zmian';
+$lang['donate'] = 'Wesprzyj projekt';
+$lang['purge_cache'] = 'Wyczyść pamięć podręczną';
+$lang['no_cache_to_purge'] = 'Nie ma czego czyścić.';
+$lang['done_purging_caches'] = 'Wyczyszczono %s bajtów pamięci podręcznej.';
+	 
 // view_jpeg_photo.php
 $lang['unsafe_file_name'] = 'Niebezpieczna nazwa pliku: ';
 $lang['no_such_file'] = 'Nie znaleziono pliku: ';
@@ -365,10 +390,12 @@ $lang['auto_update_not_setup'] = 'Zezwoliłeś/aś na automatyczne nadawanie uid
 $lang['uidpool_not_set'] = 'Określiłeś/aś mechanizm autonumerowania uid "auto_uid_number_mechanism" jako "uidpool" w konfiguracji Twojego serwera <b>%s</b>, lecz nie określiłeś/aś audo_uid_number_uid_pool_dn. Proszę określ to zanim przejdziesz dalej.';
 $lang['uidpool_not_exist'] = 'Wygląda na to, że uidPool, którą określiłeś/aś w Twojej konfiguracji ("%s") nie istnieje.';
 $lang['specified_uidpool'] = 'Określiłeś/aś "auto_uid_number_mechanism" jako "search" w konfiguracji Twojego serwera <b>%s</b>, ale nie określiłeś/aś bazy "auto_uid_number_search_base". Zrób to zanim przejdziesz dalej.';
-$lang['auto_uid_invalid_credential'] = 'Nie można podłączyć do <b>%s</b> z podaną tożsamością auto_uid. Sprawdź proszę swój plik konfiguracyjny.';
+$lang['auto_uid_invalid_credential'] = 'Nie można podłączyć do <b>%s</b> z podaną tożsamością auto_uid. Proszę sprawdzić swój plik konfiguracyjny.';
 $lang['bad_auto_uid_search_base'] = 'W Twojej konfiguracji phpLDAPadmin określona jest nieprawidłowa wartość auto_uid_search_base dla serwera %s';
 $lang['auto_uid_invalid_value'] = 'Określiłeś/aś błędną wartość dla auto_uid_number_mechanism ("%s") w konfiguracji. Tylko "uidpool" i "search" są poprawne. Proszę skorygować ten problem.';
 $lang['error_auth_type_config'] = 'Błąd: Masz błąd w pliku konfiguracji. Trzy możliwe wartości dla auth_type w sekcji $servers to \'session\', \'cookie\' oraz \'config\'.  Ty wpisałeś/aś \'%s\', co jest niedozwolone. ';
+$lang['unique_attrs_invalid_credential'] = 'Nie można podłączyć do <b>%s</b> z podaną tożsamością unique_attrs. Proszę sprawdzić swój plik konfiguracyjny.';
+$lang['unique_attr_failed'] = 'Próba dodania <b>%s</b> (<i>%s</i>) do <br><b>%s</b><br> jest NIEDOZWOLONA. Ten atrybut/wartość należy do innego wpisu.<p>Jeśli chcesz, możesz <a href=\'%s\'>poszukać</a> tego wpisu.';
 $lang['php_install_not_supports_tls'] = 'Twoja instalacja PHP nie wspiera TLS.';
 $lang['could_not_start_tls'] = 'Nie można uruchomić TLS. Proszę sprawdzić konfigurację serwera LDAP.';
 $lang['could_not_bind_anon'] = 'Nie można anonimowo podłączyć do serwera.';
@@ -458,9 +485,10 @@ $lang['searching'] = 'Szukam...';
 $lang['size_limit_exceeded'] = 'Uwaga, przekroczono limit rozmiaru wyszukiwania.';
 $lang['entry'] = 'Wpis';
 $lang['ldif_export_for_dn'] = 'Eksport LDIF dla: %s';
-$lang['generated_on_date'] = 'Wygenerowane przez phpLDAPadmin na %s';
+$lang['generated_on_date'] = 'Wygenerowane przez phpLDAPadmin ( http://phpldapadmin.sourceforge.net/ ) na %s';
 $lang['total_entries'] = 'Łącznie wpisów';
 $lang['dsml_export_for_dn'] = 'Eksport DSLM dla: %s';
+$lang['include_system_attrs'] = 'Zawiera atrybuty systemowe';
 
 // logins
 $lang['could_not_find_user'] = 'Nie można znaleźć użytkownika "%s"';
@@ -489,6 +517,7 @@ $lang['no_deletes_in_read_only'] = 'Usuwanie jest niedozwolone w trybie tylko-do
 $lang['error_calling_mass_delete'] = 'Błąd podczas wywołania mass_delete.php. Brakująca mass_delete w zmiennych POST.';
 $lang['mass_delete_not_array'] = 'zmienna POST mass_delete nie jest w tablicą.';
 $lang['mass_delete_not_enabled'] = 'Masowe usuwanie nie jest dozwolone. Odblokuj to proszę w config.php przed kontynuacją.';
+$lang['search_attrs_wrong_count'] = 'Twój config.php zawiera błąd. Ilość atrybutów w $search_attributes i$search_attributes_display jest różna';
 $lang['mass_deleting'] = 'Masowe usuwanie';
 $lang['mass_delete_progress'] = 'Postęp usuwania na serwerze "%s"';
 $lang['malformed_mass_delete_array'] = 'Zniekształcona tablica mass_delete.';
@@ -505,4 +534,84 @@ $lang['no_rdn_change'] = 'Nie zmieniłeś/aś RDN';
 $lang['invalid_rdn'] = 'Błędna wartość RDN';
 $lang['could_not_rename'] = 'Nie można zmienić nazwy wpisu';
 
+// Templates
+$lang['using'] = 'Używając';
+$lang['template'] = 'szablonu';
+$lang['switch_to'] = 'Możesz przełączyć się do ';
+$lang['default_template'] = 'domyślnego szablonu';
+
+// template_config
+$lang['user_account'] = 'Konto Użytkownika (posixAccount)';
+$lang['address_book'] = 'Wpis Książki Adresowej (inetOrgPerson)';
+$lang['kolab_user'] = 'Wpis Użytkownika Kolab';
+$lang['organizational_unit'] = 'Jednostka Organizacyjna';
+$lang['organizational_role'] = 'Rola w Organizacji';
+$lang['posix_group'] = 'Grupa Posix';
+$lang['samba_machine'] = 'Maszyna Samba NT';
+$lang['samba3_machine'] = 'Maszyna Samba 3 NT';
+$lang['samba_user'] = 'Użytkownik Samba';
+$lang['samba3_user'] = 'Użytkownik Samba 3';
+$lang['samba3_group'] = 'Przypisanie grupy Samba 3';
+$lang['dns_entry'] = 'Wpis DNS';
+$lang['simple_sec_object'] = 'Prosty obiekt bezpieczeństwa (SSO)';
+$lang['courier_mail_account'] = 'Konto Pocztowe w Courier';
+$lang['courier_mail_alias'] = 'Alias Pocztowy w Courier';
+$lang['ldap_alias'] = 'Alias w LDAP';
+$lang['custom'] = 'Ogólne';
+$lang['samba_domain_name'] = 'Moja nazwa domeny w Samba';
+$lang['administrators'] = 'Administratorzy';
+$lang['users'] = 'Użytkownicy';
+$lang['guests'] = 'Goście';
+$lang['power_users'] = 'Użytkownicy zaawansowani';
+$lang['account_ops'] = 'Operatorzy kont';
+$lang['server_ops'] = 'Operatorzy serwera';
+$lang['print_ops'] = 'Operatorzy drukowania';
+$lang['backup_ops'] = 'Operatorzy archiwizacji danych';
+$lang['replicator'] = 'Replikator';
+$lang['unable_smb_passwords'] = ' Nie można utworzyć haseł Samba. Proszę sprawdzić konfigurację w template_config.php';
+
+// Samba Account Template
+$lang['samba_account'] = 'Konto Samba';
+$lang['samba_account_lcase'] = 'konto samba';
+
+// New User (Posix) Account
+$lang['t_new_user_account'] = 'Nowe konto użytkownika';
+$lang['t_hint_customize'] = 'Wskazówka: Aby dostosować ten szablon, wyedytuj plik templates/creation/new_user_template.php';
+$lang['t_name'] = 'Nazwa/Nazwisko';
+$lang['t_first_name'] = 'Imię';
+$lang['t_last_name'] = 'Nazwisko';
+$lang['t_common_name'] = 'Nazwa';
+$lang['t_user_name'] = 'Nazwa użytkownika';
+$lang['t_password'] = 'Hasło';
+$lang['t_encryption'] = 'Szyfrowanie';
+$lang['t_login_shell'] = 'Powłoka (shell)';
+$lang['t_home_dir'] = 'Katalog domowy';
+$lang['t_uid_number'] = 'Numer UID';
+$lang['t_auto_det'] = '(automatycznie określony)';
+$lang['t_group'] = 'Grupa';
+$lang['t_gid_number'] = 'Numer GID';
+$lang['t_err_passwords'] = 'Hasła nie zgadzają się. Wróc i spróbuj ponownie.';
+$lang['t_err_field_blank'] = 'Nie możesz pozostawić pustego pola %s. Wróć i spróbuj ponownie.';
+$lang['t_err_field_num'] = 'Pole %s może zawierać tylko wartości numeryczne. Wróć i spróbuj ponownie.';
+$lang['t_err_bad_container'] = 'Kontener który wybrałeś/aś (%s) nie istnieje. Wróć i spróbuj ponownie.';
+$lang['t_confirm_account_creation'] = 'Potwierdź utworzenie konta';
+$lang['t_secret'] = '[tajne]';
+$lang['t_create_account'] = 'Utwórz konto';
+
+// New Address Template
+$lang['t_new_address'] = 'Nowy wpis w Książce Adresowej';
+$lang['t_organization'] = 'Organizacja';
+$lang['t_address'] = 'Adres';
+$lang['t_city'] = 'Miasto';
+$lang['t_postal_code'] = 'Kod pocztowy';
+$lang['t_street'] = 'Ulica';
+$lang['t_work_phone'] = 'Telefon służbowy';
+$lang['t_fax'] = 'Fax';
+$lang['t_mobile'] = 'Telefon komórkowy';
+$lang['t_email'] = 'E-mail';
+$lang['t_container'] = 'Kontener';
+$lang['t_err_cn_blank'] = 'Nie możesz pozostawić pustego pola Nazwa. Wróć i spróbuj ponownie.';
+$lang['t_confim_creation'] = 'Potwierdź utworzenie wpisu:';
+$lang['t_create_address'] = 'Utwórz adres';
+
 ?>
