@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/phpldapadmin/phpldapadmin/rename_form.php,v 1.4 2004/03/19 20:13:08 i18phpldapadmin Exp $
+// $Header: /cvsroot/phpldapadmin/phpldapadmin/rename_form.php,v 1.6 2004/08/15 17:39:20 uugdave Exp $
  
 
 /*
@@ -11,7 +11,7 @@
  *  - server_id
  */
 
-require 'common.php';
+require './common.php';
 
 $dn = $_GET['dn'];
 $encoded_dn = rawurlencode( $dn );
@@ -25,7 +25,7 @@ if( is_server_read_only( $server_id ) )
 check_server_id( $server_id ) or pla_error( $lang['bad_server_id'] );
 have_auth_info( $server_id ) or pla_error( $lang['not_enough_login_info'] );
 
-include 'header.php'; ?>
+include './header.php'; ?>
 
 <body>
 
