@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/phpldapadmin/phpldapadmin/schema.php,v 1.43 2004/04/10 15:30:59 uugdave Exp $
+// $Header: /cvsroot/phpldapadmin/phpldapadmin/schema.php,v 1.55 2004/10/24 23:51:49 uugdave Exp $
 
 
 /* 
@@ -12,20 +12,24 @@
  *  - attr (optional)
  */
  
-require 'common.php';
+require './common.php';
 
 $server_id = $_GET['server_id'];
 $view = isset( $_GET['view'] ) ? $_GET['view'] : 'objectClasses';
 $viewvalue = isset( $_GET['viewvalue'] ) ? $_GET['viewvalue'] : null; 
+if( trim( $viewvalue ) == "" )
+    $viewvalue = null;
+if( ! is_null( $viewvalue ) )
+    $viewed = false;
 
 check_server_id( $server_id ) or 
 	pla_error( $lang['bad_server_id'].": " . htmlspecialchars( $server_id ) );
 have_auth_info( $server_id ) or 
 	pla_error( $lang['not_enough_login_info']);
-pla_ldap_connect( $server_id ) or 
-	pla_error( $lang['could_not_connect']);
+$ds = pla_ldap_connect( $server_id );
+pla_ldap_connection_is_error( $ds );
 
-include 'header.php';
+include './header.php';
 
 $schema_error_str = $lang['could_not_retrieve_schema_from']." <b>" 
                     . htmlspecialchars($servers[$server_id]['name']) 
@@ -53,8 +57,8 @@ $schema_error_str = $lang['could_not_retrieve_schema_from']." <b>"
 		'<a href="?server_id=' . $server_id . '&amp;view=objectClasses">'.$lang['objectclasses'].'</a>' ); ?>
 		|
 	<?php echo ( $view=='attributes' ?
-		$lang['attributes']:
-		'<a href="?server_id=' . $server_id . '&amp;view=attributes">'.	$lang['attributes'].'</a>' ); ?>
+		$lang['attribute_types']:
+		'<a href="?server_id=' . $server_id . '&amp;view=attributes">'.	$lang['attribute_types'].'</a>' ); ?>
 		|
 	<?php echo ( $view=='syntaxes' ?
 		$lang['syntaxes'] :
@@ -77,7 +81,7 @@ if( $view == 'syntaxes' ) {
 	echo "<tr><th>" . $lang['syntax_oid'] . "</th><th>" . $lang['desc'] . "</th></tr>\n";
 	flush();
 	$counter=1;
-	$schema_syntaxes = get_schema_syntaxes( $server_id ); 
+	$schema_syntaxes = get_schema_syntaxes( $server_id, null, false ); 
 	if( ! $schema_syntaxes ) pla_error( $schema_error_str );
 	foreach( $schema_syntaxes as $syntax ) {
 		$counter++;
@@ -94,53 +98,41 @@ if( $view == 'syntaxes' ) {
 } elseif( $view == 'attributes' ) {
 	//echo "<center>" . $lang['the_following_attributes'] . "</center><br />\n";
 	flush();
-	$schema_attrs = get_schema_attributes( $server_id );
-	$schema_object_classes = get_schema_objectclasses( $server_id );
+	$schema_attrs = get_schema_attributes( $server_id, null, false );
+	$schema_object_classes = get_schema_objectclasses( $server_id, null, false );
 	if( ! $schema_attrs || ! $schema_object_classes ) 
 		pla_error( $schema_error_str );
 
-	// do a reverse-mapping to add in which objectClasses each attributeType is used
-	foreach( $schema_object_classes as $object_class ) {
-		$must_attrs = $object_class->getMustAttrNames($schema_object_classes);
-		$may_attrs = $object_class->getMayAttrNames($schema_object_classes);
-		$oclass_attrs = array_unique( array_merge( $must_attrs, $may_attrs ) );
-		foreach( $oclass_attrs as $attr_name ) {
-			if( isset( $schema_attrs[ strtolower( $attr_name ) ] ) ) {
-				$schema_attrs[ strtolower( $attr_name ) ]->addUsedInObjectClass( 
-					$object_class->getName() );
-			} else {
-				//echo "Warning, attr not set: $attr_name<br />";
-			}
-		}
-
-	}
-
 	//echo "<pre>";
 	//print_r( $schema_attrs );
 	//echo "</pre>";
 
 	?>
 	<small><?php echo $lang['jump_to_attr']; ?>:</small>
-	<form><input type="hidden" name="view" value="<?php echo $view; ?>">
-        <input type="hidden" name="server_id" value="<?php echo $server_id; ?>">
+	<form><input type="hidden" name="view" value="<?php echo $view; ?>" />
+        <input type="hidden" name="server_id" value="<?php echo $server_id; ?>" />
         <select name="viewvalue" onChange="submit()">
 	<option value=""> - all -</option>
 
 	<?php foreach( $schema_attrs as $attr ) { 		
-                    echo '<option value="'
+                    echo( '<option value="'
                          .$attr->getName()
                          .'" '
                          .( 0 == strcasecmp( $attr->getName(), $viewvalue ) ? ' selected ' : '' )
                          .'>'
                          . $attr->getName()
-		         .'</option>';
+		         .'</option>' . "\n" );
 	 } ?>
-	</select><input type="submit" value="<?php echo $lang['go']; ?>"></form>
+	</select><input type="submit" value="<?php echo $lang['go']; ?>" /></form>
 
 	<br />
 	<table class="schema_attr" width="100%">
-	<?php foreach( $schema_attrs  as $attr ) {
-	  if ( $viewvalue==null || $viewvalue==($attr->getName())){
+
+	<?php 
+    foreach( $schema_attrs  as $attr ) {
+	  if ( is_null( $viewvalue ) || 0 == strcasecmp( $viewvalue, $attr->getName() ) ) {
+        if( ! is_null( $viewvalue ) )
+            $viewed = true;
 		flush();
 		echo "<tr><th colspan=\"2\"><a name=\"" . strtolower( $attr->getName() ) . "\">";
 		echo $attr->getName() . "</a></th></tr>\n\n";
@@ -259,8 +251,8 @@ if( $view == 'syntaxes' ) {
 
 } elseif( $view == 'matching_rules' ) {
 	//echo "<center>" . $lang['the_following_matching'] . "</center><br />\n\n";
-        $schema_matching_rules = get_schema_matching_rules( $server_id ); 
-	echo $lang['jump_to_matching_rule']."<br />";
+        $schema_matching_rules = get_schema_matching_rules( $server_id, null, false ); 
+	echo '<small>' . $lang['jump_to_matching_rule'].'</small><br />';
 	echo '<form get="?">';
         echo '<input type="hidden" name="server_id" value="'.$server_id.'" />';
         echo '<input type="hidden" name="view" value="matching_rules" />';
@@ -277,14 +269,15 @@ if( $view == 'syntaxes' ) {
 	echo "<tr><th>" . $lang['matching_rule_oid'] . "</th><th>" . $lang['name'] . "</th><th>".$lang['used_by_attributes']."</th></tr>\n";
 	flush();
 	$counter=1;
-	$schema_matching_rules = get_schema_matching_rules( $server_id ); 
+	$schema_matching_rules = get_schema_matching_rules( $server_id, null, false ); 
 	if( ! $schema_matching_rules ) pla_error( $schema_error_str );
 	foreach( $schema_matching_rules as $rule ) {
 		$counter++;
 		$oid = htmlspecialchars( $rule->getOID() );
 		$desc = htmlspecialchars( $rule->getName() );
-		if ( $viewvalue==null || $viewvalue==($rule->getName() ))
-		  {	
+		if ( $viewvalue==null || $viewvalue==($rule->getName() )) {
+        if( ! is_null( $viewvalue ) )
+            $viewed = true;
 		if( null != $rule->getDescription() )
 			$desc .= ' (' . $rule->getDescription() . ')';
 		if( true === $rule->getIsObsolete() )
@@ -297,12 +290,12 @@ if( $view == 'syntaxes' ) {
 			echo "<center>(" . $lang['none'] . ")</center><br /><br />\n";
 		} else {
 			echo "<table><tr><td style=\"text-align: right\"><form>";
-                        echo "<input type=\"hidden\" name=\"server_id\" value=\"".$server_id."\">";
-			echo "<input type=\"hidden\" name=\"view\" value=\"attributes\">";
+                        echo "<input type=\"hidden\" name=\"server_id\" value=\"".$server_id."\" />";
+			echo "<input type=\"hidden\" name=\"view\" value=\"attributes\" />";
 			echo "<select style=\"width: 150px; color:black; background-color: #eee\" size=\"4\" name=\"viewvalue\">\n";
 			foreach( $rule->getUsedByAttrs() as $attr )
 				echo "<option>$attr</option>\n";
-			echo "</select><br /><input type=\"submit\" value=\"".$lang['go']."\"></form></td></tr></table>\n";
+			echo "</select><br /><input type=\"submit\" value=\"".$lang['go']."\" /></form></td></tr></table>\n";
 		}
 		echo "</td></tr>\n";
 		  }
@@ -312,12 +305,12 @@ if( $view == 'syntaxes' ) {
 } elseif( $view == 'objectClasses' ) { 
 	//echo "<center>" . $lang['the_following_objectclasses'] . "</center><br />\n";
 	flush();
-	$schema_oclasses = get_schema_objectclasses( $server_id );
+	$schema_oclasses = get_schema_objectclasses( $server_id, null, false );
 	if( ! $schema_oclasses ) pla_error( $schema_error_str );
 	?>
 	<small><?php echo $lang['jump_to_objectclass']; ?>:</small>
-	<form><input type="hidden" name="view" value="<?php echo $view; ?>">
-        <input type="hidden" name="server_id" value="<?php echo $server_id; ?>">
+	<form><input type="hidden" name="view" value="<?php echo $view; ?>" />
+        <input type="hidden" name="server_id" value="<?php echo $server_id; ?>" />
 	<select name="viewvalue"
 	onChange="submit()">
         <option value=""> - all - </option>
@@ -325,18 +318,18 @@ if( $view == 'syntaxes' ) {
 		echo '<option value="'
 		     .$oclass->getName()
                      .'"'
-                     . ($oclass->getName()==$viewvalue ? ' selected ':'')
+                     . ( 0 == strcasecmp( $oclass->getName(), $viewvalue ) ? ' selected ':'')
                      .'>'.$oclass->getName()
 		     .'</option>';
 	 } ?>
-        </select><input type="submit" value="<?php echo $lang['go']; ?>">
+        </select><input type="submit" value="<?php echo $lang['go']; ?>" />
         </form>
 
         <?php flush(); ?>
 
     <?php foreach( $schema_oclasses as $name => $oclass ) { 
         foreach( $oclass->getSupClasses() as $parent_name ) { 
-            $parent_name = strtolower( $parent_name );
+            $parent_name = $parent_name;
             if( isset( $schema_oclasses[ $parent_name ] ) ) {
                 $schema_oclasses[ $parent_name ]->addChildObjectClass( $oclass->getName() );
             }
@@ -346,7 +339,10 @@ if( $view == 'syntaxes' ) {
 
 	<br />
 	<?php foreach( $schema_oclasses as $name => $oclass ) {
-	  if ( $viewvalue==null || $viewvalue==$oclass->getName()){ ?>
+	  if ( $viewvalue==null || 0 == strcasecmp( $viewvalue, $oclass->getName() ) ){
+        if( ! is_null( $viewvalue ) )
+            $viewed = true; 
+        ?>
         
 		<h4 class="oclass"><a name="<?php echo $name; ?>"><?php echo $oclass->getName(); ?></a></h4>
 		<h4 class="oclass_sub"><?php echo $lang['OID']; ?>: <b><?php echo $oclass->getOID(); ?></b></h4>
@@ -364,7 +360,7 @@ if( $view == 'syntaxes' ) {
 		else
 			foreach( $oclass->getSupClasses() as $i => $object_class ) {
 				echo '<a title="' . $lang['jump_to_this_oclass'] . ' " 
-					href="?server_id='.$server_id.'&view='.$view.'&amp;viewvalue='.htmlspecialchars( $object_class ) ;
+					href="?server_id='.$server_id.'&amp;view='.$view.'&amp;viewvalue='.htmlspecialchars( $object_class ) ;
 				echo '">' . htmlspecialchars( $object_class ) . '</a>';
 				if( $i < count( $oclass->getSupClasses() ) - 1 )
 					echo ', ';
@@ -441,6 +437,10 @@ if( $view == 'syntaxes' ) {
 	<?php }  } /* End foreach objectClass */ ?>
 <?php } /* End else (displaying objectClasses */ ?>
 
+<?php if( ! is_null( $viewvalue ) && ! $viewed )
+    pla_error( sprintf( $lang['no_such_schema_item'], htmlspecialchars( $viewvalue ) ) );
+?>
+
 </body>
 
 </html>
