@@ -1,7 +1,5 @@
 <?php
-// $Header: /cvsroot/phpldapadmin/phpldapadmin/templates/creation/new_smb3_user_template.php,v 1.15 2004/04/29 13:17:02 xrenard Exp $
-
-require realpath( 'common.php' );
+// $Header: /cvsroot/phpldapadmin/phpldapadmin/templates/creation/new_smb3_user_template.php,v 1.23 2004/12/16 22:59:50 uugdave Exp $
 
 $samba3_domains = get_samba3_domains();
 
@@ -18,7 +16,7 @@ if( isset($_POST['step']) )
      
      //check if the sambaSamAccount objectClass is availaible
      if( get_schema_objectclass( $server_id, 'sambaSamAccount' ) == null )
-     pla_error( "You LDAP server does not have schema support for the sambaSamAccount objectClass. Cannot continue." );
+     pla_error( "Your LDAP server does not have schema support for the sambaSamAccount objectClass. Cannot continue." );
      
      check_server_id( $server_id ) or pla_error( "Bad server_id: " . htmlspecialchars( $server_id ) );
      have_auth_info( $server_id ) or pla_error( "Not enough information to login to server. Please check your configuration." );
@@ -54,10 +52,17 @@ function autoFillHomeDir( form ){
 function autoFillSambaRID( form ){
   var sambaRID;
   var uidNumber;
-  // TO DO:need to check if uidNumber is an integer
-  uidNumber = form.uid_number.value;
-  sambaRID = (2*uidNumber)+1000;
-  form.samba3_user_rid.value = sambaRID;
+  
+  //check if the UID Number is a number
+  if(!isNaN(form.uid_number.value)){
+    uidNumber = form.uid_number.value;
+    sambaRID = (2*uidNumber)+1000;
+    form.samba3_user_rid.value = sambaRID;
+  }
+  // otherwise (re)set the samba rid value to an empty string
+  else{
+    form.samba3_user_rid.value = "";
+  }
 }
 function autoFillSambaGroupRID( form ){
   var gidNumber;
@@ -90,11 +95,14 @@ function autoFillSambaGroupRID( form ){
 
 <center>
 <table class="confirm">
-<tr class="spacer"><td colspan="3"></tr>
+<tr class="spacer"><td colspan="3"></td></tr>
 <tr>
 	<td></td>
 	<td class="heading">UID Number:</td>
-	<td><input type="text" name="uid_number" value="" onChange="autoFillSambaRID(this.form)" /></td>
+        <?php $next_uid_number = get_next_uid_number( $server_id ); ?>
+	<td><input type="text" name="uid_number" value="<?php echo $next_uid_number; ?>"  onChange="autoFillSambaRID(this.form)" />
+	   <?php if( false !== $next_uid_number ) echo "<small>(automatically determined)</small>"; ?>
+       </td>
 </tr>
 <tr>
 	<td></td>
@@ -102,9 +110,9 @@ function autoFillSambaGroupRID( form ){
 	<td><select name="samba3_domain_sid">
 <?php foreach($samba3_domains as $samba3_domain) ?>
       <option value="<?php echo $samba3_domain['sid'] ?>"><?php echo $samba3_domain['sid'] ?></option>
-</select> - <input type="text" name="samba3_user_rid" id="samba3_user_rid" value="" size="7"/></td>
+</select> - <input type="text" name="samba3_user_rid" id="samba3_user_rid" value="" size="7" onfocus="autoFillSambaRID(this.form)"/></td>
 </tr>
-<tr class="spacer"><td colspan="3"></tr>
+<tr class="spacer"><td colspan="3"></td></tr>
 <tr>
 	<td><img src="images/uid.png" /></td>
 	<td class="heading">First name:</td>
@@ -121,7 +129,7 @@ function autoFillSambaGroupRID( form ){
 	<td><input type="text" name="user_name" id="user_name" value=""
 		onChange="autoFillHomeDir(this.form)" onExit="autoFillHomeDir(this.form,this)" /></td>
 </tr>
-<tr class="spacer"><td colspan="3"></tr>
+<tr class="spacer"><td colspan="3"></td></tr>
 <tr>
 	<td><img src="images/lock.png" /></td>
 	<td class="heading">User Password:</td>
@@ -150,7 +158,7 @@ function autoFillSambaGroupRID( form ){
 	<td>
             <div style="font-size: 90%;">
              <div>
-               <input type="radio" name="samba_pass_mode" checked value="1" />
+               <input type="radio" name="samba_pass_mode" checked="true" value="1" />
                <span style="font-size: 90%;">Use Unix Password</span>
              </div>
              <div>
@@ -167,7 +175,7 @@ function autoFillSambaGroupRID( form ){
          <td><input type="radio" name="samba_pass_mode" style="margin-left:0px;" value="4" />              <span style="font-size: 90%;">New Password :</span> </td>
         <td>
          <div><input type="password" name="samba_pass1" /></div>
-<div style="padding-top:3px;" ><input type="password" name="samba_pass2"  /></div>
+<div style="padding-top:3px"><input type="password" name="samba_pass2" /></div>
 </td>
 </tr>
 </table>
@@ -185,7 +193,7 @@ function autoFillSambaGroupRID( form ){
          </div>
           <div style="padding-top:3px;" >
           <span style="font-size: 90%;">NT Password: </span>
-          <span style="padding-left:20px;"><input type="text" name="ntpassword"  /></span>
+          <span style="padding-left:20px;"><input type="text" name="ntpassword" /></span>
         </div>
        </td>
       </tr>
@@ -195,7 +203,7 @@ function autoFillSambaGroupRID( form ){
 		</td>
 </tr>
 
-<tr class="spacer"><td colspan="3"></tr>
+<tr class="spacer"><td colspan="3"></td></tr>
 <tr>
 	<td><img src="images/terminal.png" /></td>
 	<td class="heading">Login Shell:</td>
@@ -219,13 +227,13 @@ function autoFillSambaGroupRID( form ){
 				echo htmlspecialchars( $container );
 			     else
 				echo htmlspecialchars( $default_container . ',' . $servers[$server_id]['base'] ); ?>" />
-		<?php draw_chooser_link( 'user_form.container' ); ?></td>
+		<?php draw_chooser_link( 'user_form.container' ); ?>
 	</td>
 </tr>
 <tr>
 	<td></td>
 	    <?php $posix_groups_found = ( is_array( $posix_groups )?1:0 );?>
-	<td class="heading"><?echo $posix_groups_found?"Unix Group":"GID Number"?>:</td>
+	<td class="heading"><?php echo $posix_groups_found?"Unix Group":"GID Number"?>:</td>
 	    <td>
 	    <?php if( $posix_groups_found ){?>
 	       <select name="gid_number" onchange="autoFillSambaGroupRID( this.form )">
@@ -235,7 +243,7 @@ function autoFillSambaGroupRID( form ){
 		 <option value="<?php echo $attrs['gidNumber'];?>"><?php echo $group_name;?> </option> 
 		 <?php } ?>
 	       </select>
-		   <?php }else{ ?><input type="text" name="gid_number"><?php } ?>
+		   <?php }else{ ?><input type="text" name="gid_number" /><?php } ?>
 <br />
 </td>
 </tr>
@@ -245,12 +253,12 @@ function autoFillSambaGroupRID( form ){
 	<td>
           <div style="font-size: 90%">
             <div>
-              <div><input type="radio" name="samba_group" value="1" checked onchange="autoFillSambaGroupRID( this.form )" /> <span style="text-decoration:underline;">Built-In:</span></div>
+              <div><input type="radio" name="samba_group" value="1" checked="true" onchange="autoFillSambaGroupRID( this.form )" /> <span style="text-decoration:underline;">Built-In:</span></div>
                <div style="padding-top: 3px;">
                  <select name="builtin_sid">
                      <optgroup label="Local Group">
    <?php foreach( $built_in_local_groups as $sid => $name ){ ?>
-                         <option value="<?php echo $sid; ?>"><?php echo $name; ?> (<?php echo $sid; ?>)</option>  <?  } ?>
+                         <option value="<?php echo $sid; ?>"><?php echo $name; ?> (<?php echo $sid; ?>)</option>  <?php  } ?>
 	              </optgroup>
                       <optgroup  label="Global Groups">
 			<?php foreach($samba3_domains as $samba3_domain) { ?>
@@ -263,7 +271,7 @@ function autoFillSambaGroupRID( form ){
                </div>
             </div>
             <div style="padding-top:10px;">
-               <div><input type="radio" name="samba_group" value="2" onchange="autoFillSambaGroupRID( this.form )"> <span style="text-decoration:underline;">Custom:</span></div>
+               <div><input type="radio" name="samba_group" value="2" onchange="autoFillSambaGroupRID( this.form )" /> <span style="text-decoration:underline;">Custom:</span></div>
                <div style="padding-top:3px;">
                   <select name="custom_domain_sid">
 <?php foreach($samba3_domains as $samba3_domain) { ?>
@@ -282,16 +290,18 @@ function autoFillSambaGroupRID( form ){
 	<td><input type="text" name="home_dir" value="" id="home_dir" /></td>
 </tr>
 <tr>
-	<td colspan="3"><center><br /><input type="submit" value="Proceed &gt;&gt;" /></td>
+	<td colspan="3" style="text-align: center"><br /><input type="submit" value="Proceed &gt;&gt;" /></td>
 </tr>
-<tr height="10"><td colspan="3"></tr>
-<tr class="spacer"><td colspan="3"></tr>
+<tr height="10"><td colspan="3"></td></tr>
+<tr class="spacer"><td colspan="3"></td></tr>
 <tr>
 <td><small><b>Note: </b></small></td>
-<td colspan="2"><small>To change the value(s) of the samba domain sid, please edit the file :<br /> <code>templates/template_config.php</small></code></td>
+<td colspan="2"><small>To change the value(s) of the samba domain sid, please edit the file :<br /> <code>templates/template_config.php</code></small></td>
 </tr>
 </table>
 </center>
+</form>
+
 
 <?php } elseif( $step == 2 ) {
 
