@@ -1,8 +1,8 @@
 <?php
-// $Header: /cvsroot/phpldapadmin/phpldapadmin/view_jpeg_photo.php,v 1.5 2004/03/19 20:13:08 i18phpldapadmin Exp $
+// $Header: /cvsroot/phpldapadmin/phpldapadmin/view_jpeg_photo.php,v 1.6 2004/08/15 17:39:20 uugdave Exp $
 
 
-require 'common.php';
+require './common.php';
 
 $file = $_GET['file'];
 
